package App::manwrap::pm;

our $DATE = '2017-07-29'; # DATE
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: man + Perl stuffs

__END__

=pod

=encoding UTF-8

=head1 NAME

App::manwrap::pm - man + Perl stuffs

=head1 VERSION

This document describes version 0.004 of App::manwrap::pm (from Perl distribution App-manwrap-pm), released on 2017-07-29.

=head1 SYNOPSIS

See L<manwrap-pm> included in this distribution.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-manwrap-pm>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-manwrap-pm>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-manwrap-pm>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<pmman> from L<App::PMUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
